/**
 * Check highlight keyword for browser support at CanIUse.com
 *
 * With this plugin, you can check the browser support for CSS properties and HTML elements
 * that you are using. To use it, highlight the CSS property or the HTML element and activate the plugin.
 * Then it will bring you to the appropriate page at CanIUse.com.
 *
 * @category  WeBuilder Plugin
 * @package   Can I use Integration
 * @author    Peter Klein <pmk@io.dk>
 * @copyright 2015
 * @license   http://www.freebsd.org/copyright/license.html  BSD License
 * @version   1.0
 */

/**
 * [CLASS/FUNCTION INDEX of SCRIPT]
 *
 *     40   function UrlEncode(str)
 *     55   function SearchCanIUse()
 *     84   function OnExit()
 *     98   function OnInstalled()
 *
 * TOTAL FUNCTIONS: 4
 * (This index is automatically created/updated by the WeBuilder plugin "DocBlock Comments")
 *
 */

 var win = null;
var web = null;

/**
 * Helper function: UrlEncode string
 * Reference: http://xkr.us/articles/javascript/encode-compare/
 *
 * @param  string   str
 *
 * @return string
 */
function UrlEncode(str) {
	var out = "",	glyph;
	for (var i=1;i<=Length(str);i++) {
		glyph = Copy(str, i, 1);
		if (RegexMatch(glyph, "[~!@#$&*()=:\\/,;?+'\\da-zA-Z]", false) != "") out += glyph;
		else out += Format("%%%.2x",[Ord(glyph)]);
	}
	return out;
}

/**
 * Opens browser window at http://caniuse.com with the first keyword in selection
 *
 * @return void
 */
function SearchCanIUse() {
	var keyword = RegexReplace(Trim(Editor.SelText), "([\\s:;].*)$", "", true);
	if ((keyword != "") && (Document.CurrentCodeType in [dtHTML, dtCSS, dtApache, dtSass, dtLess])) {
		var url = "http://caniuse.com/#search=" + UrlEncode(keyword)

	  if (win == null) {
	    win = new TForm(WeBuilder);
	    win.width = 800;
	    win.Height = 600;
	    win.Caption = "CanIUse";

	    web = Script.CreateScriptableWebKit(win, url, "");
	    web.Webkit.Top = 0;
	    web.Webkit.Left = 0;
	    web.Webkit.Width = win.ClientWidth;
	    web.Webkit.Height = win.ClientHeight;
	    web.Webkit.Anchors = akLeft || akRight || akTop || akBottom;
	  } else {
	    web.Webkit.Load(url);
	  }
	  win.Show;
	}
}

/**
 * Cleanup function when plugin is disabled or editor is closed
 *
 * @return void
 */
function OnExit() {
  if (web != null) {
    delete web;
  }
  if (win != null) {
    delete win;
  }
}

/**
 * Show info when plugin is installed
 *
 * @return void
 */
function OnInstalled() {
  alert("Can I Use 1.0 by Peter Klein installed sucessfully!");
}

Script.ConnectSignal("installed", "OnInstalled");
Script.ConnectSignal("exit", "OnExit");
Script.RegisterDocumentAction("", "Can I Use", "", "SearchCanIUse");
